ResponseCodes class

Razorpay response codes

Constructors

ResponseCodes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BASE_REQUEST_ERROR → const int
Base request error code
CODE_PAYMENT_ERROR → const int
Error response code
CODE_PAYMENT_EXTERNAL_WALLET → const int
External wallet response code
CODE_PAYMENT_SUCCESS → const int
Success response code
INCOMPATIBLE_PLUGIN → const int
Incompatible plugin error code
INVALID_OPTIONS → const int
Invalid options error code
NETWORK_ERROR → const int
Network error code
PAYMENT_CANCELLED → const int
Payment cancelled error code
TLS_ERROR → const int
TLS error code
UNKNOWN_ERROR → const int
Unknown error code